"use strict";

var AbstractMarker = require('./AbstractMarker');

/**
 * This class describes Google maps marker (connected to {@link Reaction}) that
 * is visualized on the map.
 */
function ReactionMarker(params) {
  AbstractMarker.call(this, params);
}
ReactionMarker.prototype = Object.create(AbstractMarker.prototype);
ReactionMarker.prototype.constructor = ReactionMarker;

ReactionMarker.prototype.init = function() {
  var self = this;
  return self.getCustomMap().getModel().getReactionById(self.getId()).then(function(reactionData) {
    self.setReactionData(reactionData);
    return self._init();
  }).then(function() {
    self.show();
  });
};

/**
 * Returns {@link Reaction} data for this marker.
 * 
 * @returns {@link Reaction} data for this marker
 */
ReactionMarker.prototype.getReactionData = function() {
  return this._reactionData;
};

/**
 * Sets {@link Reaction} data for this marker.
 * 
 * @param data
 *          {@link Reaction} data for this marker
 */
ReactionMarker.prototype.setReactionData = function(data) {
  this._reactionData = data;
};

/**
 * Returns coordinates where marker is pointing.
 * 
 * @returns {google.maps.Point} - coordinates where marker is pointing
 */
ReactionMarker.prototype.getCoordinates = function() {
  return new google.maps.Point(this._reactionData.getCenter().x, this._reactionData.getCenter().y);
};

module.exports = ReactionMarker;
